@@ -103,10 +103,10 @@ static void PrintHelp(const char* extra_msg) {
 
 static void PrintVersion() {
   llvm::outs() << "include-what-you-use " << IWYU_VERSION_STRING;
-  // IWYU_SVN_REVISION should be provided by build system.
-  string iwyu_svn_revision = IWYU_SVN_REVISION;
-  if (!iwyu_svn_revision.empty()) {
-    llvm::outs() << " (" << iwyu_svn_revision << ")";
+  // IWYU_GIT_REV should be provided by build system.
+  string iwyu_rev = IWYU_GIT_REV;
+  if (!iwyu_rev.empty()) {
+    llvm::outs() << " (git:" << iwyu_rev << ")";
   }
   llvm::outs() << " based on " << clang::getClangFullVersion()
                << "\n";
@@ -283,7 +283,6 @@ static vector<HeaderSearchPath> NormalizeHeaderSearchPaths(
     include_dirs.push_back(HeaderSearchPath(it->first, it->second));
   }
 
-
   sort(include_dirs.begin(), include_dirs.end(), &SortByDescendingLength);
   return include_dirs;
 }
@@ -297,7 +296,7 @@ static vector<HeaderSearchPath> ComputeHeaderSearchPaths(
            it = header_search->system_dir_begin();
        it != header_search->system_dir_end(); ++it) {
     if (const DirectoryEntry* entry = it->getDir()) {
-      const string path = CanonicalizeFilePath(entry->getName());
+      const string path = CanonicalizeHeaderSearchPath(entry->getName());
       search_path_map[path] = HeaderSearchPath::kSystemPath;
     }
   }
@@ -308,7 +307,7 @@ static vector<HeaderSearchPath> ComputeHeaderSearchPaths(
       // search_dir_begin()/end() includes both system and user paths.
       // If it's a system path, it's already in the map, so everything
       // new is a user path.  The insert only 'takes' for new entries.
-      const string path = CanonicalizeFilePath(entry->getName());
+      const string path = CanonicalizeHeaderSearchPath(entry->getName());
       search_path_map.insert(make_pair(path, HeaderSearchPath::kUserPath));
     }
   }
@@ -406,11 +405,12 @@ void InitGlobalsAndFlagsForTesting() {
 
   // Use a reasonable default for the -I flags.
   map<string, HeaderSearchPath::Type> search_path_map;
-  search_path_map["/usr/include"] = HeaderSearchPath::kSystemPath;
-  search_path_map["/usr/include/c++/4.3"] = HeaderSearchPath::kSystemPath;
-  search_path_map["/usr/include/c++/4.2"] = HeaderSearchPath::kSystemPath;
-  search_path_map["."] = HeaderSearchPath::kUserPath;
-  search_path_map["/usr/src/linux-headers-2.6.24-gg23/include"] = HeaderSearchPath::kSystemPath;
+  search_path_map["/usr/include/"] = HeaderSearchPath::kSystemPath;
+  search_path_map["/usr/include/c++/4.3/"] = HeaderSearchPath::kSystemPath;
+  search_path_map["/usr/include/c++/4.2/"] = HeaderSearchPath::kSystemPath;
+  search_path_map["./"] = HeaderSearchPath::kUserPath;
+  search_path_map["/usr/src/linux-headers-2.6.24-gg23/include/"] =
+      HeaderSearchPath::kSystemPath;
 
   SetHeaderSearchPaths(NormalizeHeaderSearchPaths(search_path_map));
 }
