@@ -48,9 +48,10 @@ using clang::FunctionDecl;
 using clang::NamedDecl;
 using clang::NamespaceDecl;
 using clang::RecordDecl;
+using clang::SourceLocation;
 using clang::SourceRange;
 using clang::TemplateDecl;
-using clang::SourceLocation;
+using clang::UsingDecl;
 using llvm::cast;
 using llvm::errs;
 using llvm::isa;
@@ -60,6 +61,7 @@ using std::map;
 using std::multimap;
 using std::pair;
 using std::sort;
+using std::to_string;
 using std::vector;
 
 namespace internal {
@@ -72,53 +74,61 @@ class OutputLine {
   explicit OutputLine(const string& line)
       : line_(line) {}
   OutputLine(const string& line, const vector<string>& symbols)
-      : line_(line), symbols_(symbols) {}
+      : line_(line),
+        symbols_(symbols) {
+    symbols_.erase(std::remove_if(symbols_.begin(), symbols_.end(),
+                                  [](const string& v) { return v.empty(); }),
+                   symbols_.end());
+  }
 
   size_t line_length() const { return line_.size(); }
   bool needs_alignment() const { return !symbols_.empty(); }
   void add_prefix(const string& prefix) { line_ = prefix + line_; }
-  string printable_line(size_t desired_length, size_t max_length) const;
+  string printable_line(size_t min_length, size_t max_length) const;
 
  private:
   string line_;                     // '#include XXX' or 'class YYY;'
   vector<string> symbols_;          // symbols used from included header
 };
 
-string OutputLine::printable_line(size_t desired_length, size_t max_length)
-    const {
-  // Reduce max_length to make room for the ", etc" suffix.
-  max_length -= strlen(", etc");
+// Append a helpful 'why' comment to the include line, containing the symbols
+// used from the header. Align nicely at lower verbosity levels.
+string OutputLine::printable_line(size_t min_length, size_t max_length) const {
+  // If there are no symbols to mention, return the line as-is.
+  if (symbols_.empty())
+    return line_;
 
-  desired_length = std::min(desired_length, max_length);
+  CHECK_(max_length > 0);
+  --max_length;  // Spare a char for newline character.
 
-  string retval = line_;
+  // Before first symbol, print '  // for ' and pad it so 'why' comments are
+  // nicely aligned.
+  string symbol_prefix = "  // for ";
+  if (line_.length() < min_length)
+    symbol_prefix.insert(0, min_length - line_.length(), ' ');
 
-  string prefix;   // what we print before each symbol in the 'why' comments
-  // We try to get the columns to line up nicely.
-  if (retval.length() < desired_length)
-    prefix += string(desired_length - retval.length(), ' ');
-  prefix += "  // for ";    // before 1st symbol, print ' // for '
-  int symbols_printed = 0;
+  string result = line_;
+  for (string symbol : symbols_) {
+    // At verbose levels 0-2, truncate output to max_length columns.
+    if (!ShouldPrint(3)) {
+      // Calculate number of chars remaining.
+      size_t remaining = 0;
+      size_t result_length = result.length() + symbol_prefix.length();
+      if (result_length < max_length)
+        remaining = max_length - result_length;
 
-  for (Each<string> it(&symbols_); !it.AtEnd(); ++it) {
-    if (it->empty())       // ignore the empty ("") symbol
-      continue;
-    // At verbose levels of 0, 1, or 2, cut off output at max_length columns.
-    // Actually, at 74, to leave 5 chars for ', etc' and 1 for newline.
-    if (ShouldPrint(3) ||
-        retval.length() + prefix.length() + it->length() <= max_length) {
-      retval += prefix + *it;
-      ++symbols_printed;
-      prefix = ", ";       // before 2nd and subsequent symbols, print ', '
-    } else {
-      // Truncate at max_length cols.
-      if (symbols_printed > 0)
-        retval += ", etc";
-      break;
+      // Ellipsize, and if we can't fit any fragment of the symbol, give up.
+      symbol = Ellipsize(symbol, remaining);
+      if (symbol.empty())
+        break;
     }
+
+    result += symbol_prefix;
+    result += symbol;
+    symbol_prefix = ", ";
   }
-  retval += "\n";
-  return retval;
+
+  return result;
 }
 
 // A map that effectively allows us to dynamic cast from a NamedDecl
@@ -537,6 +547,19 @@ void IwyuFileInfo::AddForwardDeclare(const clang::NamedDecl* fwd_decl,
            << internal::GetQualifiedNameAsString(fwd_decl) << "\n";
 }
 
+void IwyuFileInfo::AddUsingDecl(const UsingDecl* using_decl) {
+  CHECK_(using_decl && "using_decl unexpectedly NULL");
+  using_decl_referenced_.insert(std::make_pair(using_decl, false));
+  const SourceRange decl_lines = using_decl->getSourceRange();
+  int start_linenum = GetLineNumber(GetInstantiationLoc(decl_lines.getBegin()));
+  int end_linenum = GetLineNumber(GetInstantiationLoc(decl_lines.getEnd()));
+  VERRS(6) << "Found using-decl: "
+           << GetFilePath(file_) << ":" 
+           << to_string(start_linenum) << "-" << to_string(end_linenum) << ": " 
+           << internal::PrintablePtr(using_decl)
+           << internal::GetQualifiedNameAsString(using_decl) << "\n";
+}
+
 static void LogSymbolUse(const string& prefix, const OneUse& use) {
   string decl_loc;
   string printable_ptr;
@@ -605,6 +628,28 @@ void IwyuFileInfo::ReportForwardDeclareUse(SourceLocation use_loc,
   LogSymbolUse("Marked fwd-decl use of decl", symbol_uses_.back());
 }
 
+void IwyuFileInfo::ReportUsingDeclUse(SourceLocation use_loc,
+                                      const UsingDecl* using_decl,
+                                      bool in_cxx_method_body,
+                                      const char* comment) {  
+  // If accessing a symbol through a using decl in the same file that contains
+  // the using decl, we must mark the using decl as referenced. At the end of
+  // traversing the AST, we check to see if a using decl is unreferenced and
+  // add a full use of one of its shadow decls so that the source file
+  // continues to compile.
+  map<const UsingDecl*, bool>::iterator using_decl_status = 
+    using_decl_referenced_.find(using_decl);
+
+  if (using_decl_status != using_decl_referenced_.end()) {
+    using_decl_status->second = true;
+  }
+
+  // When a symbol is accessed through a using decl, we must report
+  // that as a full use of the using decl because whatever file that
+  // using decl is in is now required.
+  ReportFullSymbolUse(use_loc, using_decl, in_cxx_method_body, comment);
+}
+
 // Given a collection of symbol-uses for symbols defined in various
 // files, figures out the minimal set of #includes needed to get those
 // definitions.  Typically this is a trivial task: if we need the full
@@ -1826,6 +1871,7 @@ size_t PrintableDiffs(const string& filename,
   // Align lines and produce final output.
   for (Each<OutputLine> it(&output_lines); !it.AtEnd(); ++it) {
     output += it->printable_line(line_length, max_line_length);
+    output += "\n";
   }
 
   // Let's print a helpful separator as well.
@@ -1836,6 +1882,35 @@ size_t PrintableDiffs(const string& filename,
 
 }  // namespace internal
 
+void IwyuFileInfo::ResolvePendingAnalysis() {
+  // Resolve using declarations:  This handles the case where there's a using
+  // declaration in the file but no code is actually using it. If that
+  // happens, we might try to remove all of the headers with the decls that
+  // the using decl is referencing, which would result in a compilation error
+  // at best. A possible solution is to remove the using decl if it's not
+  // used, but that doesn't work for header files because a using decl in a
+  // header is an exported symbol, so we don't want to do that either. As a
+  // compromise, we arbitrarily add the first shadow decl to make sure
+  // everything still compiles instead of removing the using decl. A more
+  // thorough approach would be to scan the current list of includes that
+  // already name this decl (like in the overloaded function case) and include
+  // one of those so we don't include a file we don't actually need.
+  for (map<const UsingDecl*, bool>::value_type using_decl_status
+      : using_decl_referenced_) {
+    if (!using_decl_status.second) {
+      const UsingDecl* using_decl = using_decl_status.first;
+      // It should not be possible to get here with a using decl without any
+      // shadow decls because doing so would imply that the input code we're
+      // analyzing code doesn't compile.
+      CHECK_(using_decl->shadow_size() > 0);
+      ReportForwardDeclareUse(using_decl->getUsingLoc(),
+        using_decl->shadow_begin()->getTargetDecl(),
+        /* in_cxx_method_body */ false,
+        "(for un-referenced using)");
+    }
+  }
+}
+
 size_t IwyuFileInfo::CalculateAndReportIwyuViolations() {
   // This is used to calculate our own desired includes.  That depends
   // on what our associated files' desired includes are: if we use
